De `KnwlGraph` class is not a full-fledged graph implementation, but rather a simple container for nodes and edges. If you need graph analytics or algorithms, consider using libraries like NetworkX or igraph in conjunction with Knwl. If you ingest data into a graph database like Memgraph or Neo4j you will find therein a wealth of graph algorithms and query capabilities.

